"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var react_1 = tslib_1.__importDefault(require("react"));
var react_dom_1 = require("react-dom");
var context_1 = require("./context");
var renamedParametersMap = [
    ["onError", "error-callback"],
    ["onExpired", "expired-callback"],
    ["onSuccess", "callback"],
];
var ReCaptcha = /** @class */ (function (_super) {
    tslib_1.__extends(ReCaptcha, _super);
    function ReCaptcha() {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        var _this = _super.apply(this, tslib_1.__spread(args)) || this;
        _this.containerRef = react_1.default.createRef();
        _this.widget = document.createElement("div");
        _this.portalRoot = document.createElement("div");
        _this.execute = function () { return grecaptcha.execute(_this.widgetId); };
        _this.getResponse = function () { return grecaptcha.getResponse(_this.widgetId); };
        _this.reset = function () { return grecaptcha.reset(_this.widgetId); };
        _this.renderCaptcha = function () {
            var container = _this.containerRef.current;
            var parameters = tslib_1.__assign({}, _this.props);
            delete parameters.children;
            if (container.contains(_this.widget)) {
                container.removeChild(_this.widget);
            }
            _this.widget = document.createElement("div");
            container.appendChild(_this.widget);
            renamedParametersMap.forEach(function (_a) {
                var _b = tslib_1.__read(_a, 2), a = _b[0], b = _b[1];
                parameters[b] = parameters[a];
                delete parameters[a];
            });
            _this.widgetId = grecaptcha.render(_this.widget, parameters, true);
        };
        Object.defineProperty(_this, "ready", {
            configurable: true,
            enumerable: true,
            get: function () { return _this.props.context.status === context_1.Status.Loaded; },
        });
        return _this;
    }
    ReCaptcha.prototype.componentDidMount = function () {
        if (this.props.size === "invisible") {
            document.body.appendChild(this.portalRoot);
        }
        if (this.props.context.status === context_1.Status.Loaded) {
            this.renderCaptcha();
        }
    };
    ReCaptcha.prototype.componentDidUpdate = function (prevProps) {
        if (this.props.context.status !== context_1.Status.Loaded) {
            return;
        }
        if (this.props.size !== prevProps.size) {
            if (this.props.size === "invisible") {
                document.body.appendChild(this.portalRoot);
            }
            else if (prevProps.size === "invisible") {
                document.body.removeChild(this.portalRoot);
            }
        }
        this.renderCaptcha();
    };
    ReCaptcha.prototype.componentWillUnmount = function () {
        if (document.body.contains(this.portalRoot)) {
            document.body.removeChild(this.portalRoot);
        }
    };
    ReCaptcha.prototype.render = function () {
        var widget = react_1.default.createElement("div", { ref: this.containerRef });
        return this.props.size === "invisible"
            ? react_dom_1.createPortal(widget, this.portalRoot)
            : widget;
    };
    return ReCaptcha;
}(react_1.default.PureComponent));
var ReCaptchaWithConsumer = context_1.consumerHOC()(function (_a) {
    var forwardRef = _a.forwardRef, props = tslib_1.__rest(_a, ["forwardRef"]);
    return (react_1.default.createElement(ReCaptcha, tslib_1.__assign({}, props, { ref: forwardRef })));
});
var ReCaptchaWithRefForwarding = react_1.default.forwardRef(function (props, ref) { return (react_1.default.createElement(ReCaptchaWithConsumer, tslib_1.__assign({}, props, { forwardRef: ref }))); });
exports.default = ReCaptchaWithRefForwarding;
//# sourceMappingURL=index.js.map